# -*- coding: utf-8 -*-
import yaml
import os

from astakos.im.tests.common import get_local_user
from survey import forms
from survey.models import Survey

TESTS_FILE = os.path.abspath(__file__).replace("tests.py", "")
BASE_DIR = os.path.abspath(os.path.dirname(TESTS_FILE))
TEST_FILE = os.path.join(BASE_DIR, 'test.yml')

from django.test import TestCase

class TestSurvey(TestCase):

    def setUp(self):
        self.data = file(TEST_FILE).read()

    def test_import(self):
        s, created = Survey.objects.load(yaml.load(self.data))
        s.set_i18n('el')
        s.set_i18n('en')
        for q in s.questions.active().order_by('order'):
            q.set_i18n('en')

    def test_form(self):
        s, created = Survey.objects.load(yaml.load(self.data))
        c = self.client.get("/astakos/ui/survey/grnet-cloud/")
        u = get_local_user("user@synnefo.org")
        form = forms.SurveySubmitForm.from_instance(s, data={
            'Q01': 'C8',
            'Q01_0_input': 'q1 text',
            'Q01_0_input': 'q2 text',
            'Q02': 'C1',
            'Q03_0_input': 'q3 text',
            'Q03': [u'C1', 'C9'],
        })
        html = form.as_ul()
        self.assertTrue(form.is_valid())
        form.save(u)
        self.assertEqual(s.submissions.get().answers.count(), 4)

