import string
from datetime import datetime

from optparse import make_option

from django.core import management
from django.db import transaction
from django.core.management.base import BaseCommand, CommandError
from django.contrib.auth.models import Group
from django.core.exceptions import ValidationError
from django.core.validators import validate_email

from synnefo.util import units
from survey.models import Survey


class Command(BaseCommand):
    args = "<survey ID>"
    help = "Modify survey status"

    option_list = BaseCommand.option_list + (
        make_option('--set-active',
                    action='store_true',
                    dest='active',
                    default=False,
                    help="Change survey state to active"),
        make_option('--set-inactive',
                    action='store_true',
                    dest='inactive',
                    default=False,
                    help="Change survey state to inactive"),
    )

    @transaction.commit_on_success
    def handle(self, *args, **options):
        if len(args) != 1:
            raise CommandError("Please provide a survey ID")

        try:
            survey = Survey.objects.select_for_update().\
                get(id=int(args[0]))
        except Survey.DoesNotExist:
            raise CommandError("Invalid user ID")

        if options.get('active'):
            survey.is_active = True
            survey.save()
            print "Survey %s activated" % survey.sid

        elif options.get('inactive'):
            survey.is_active = False
            survey.save()
            print "Survey %s deactivated" % survey.sid

